# Versioning and changelog

The changelog is prepared manually immediately before a release, by moving changelog entries from `polaris-react/UNRELEASED.md` to `polaris-react/CHANGELOG.md`, under a new heading for the version number.

**Use the [`🤖Skip Changelog`](https://github.com/Shopify/polaris/issues?q=is%3Aopen+is%3Aissue+label%3A%22%F0%9F%A4%96Skip+Changelog%22) label to ignore a failing changelog check** in your pull request if you feel the code changes do not warrant a changelog entry.

### How to write a changelog entry:

- Use a positive, conversational tone (for example, use “support” over “allow” and other authoritative verbs)
- Avoid redundancy when possible (try to phrase a bug fix entry without the word “bug”)
- Use sentence case
- Use plain language

### Component name formats:

When referring to the concept of a component: use sentence case and include a space. For example, write “text field” instead of “TextField”. This format helps non-developers with documentation comprehension.

When referring to an actual React component:

- Refer to components by their React name (singular).
  - **Do:** Banner, Tabs, ResourceList
  - **Don’t:** Banners, Avatars, resource list.
- **Components:** use upper CamelCase, also known as PascalCase, wrapped in backticks. For example, `TextField`.
- **Props:** use lower camelCase, wrapped in backticks. For example `primaryAction`.
- **Putting it all together:** “Added a `primaryAction` prop to `TextField`”.

Change log entry descriptions should be brief but descriptive and follow this structure:

```md
## 2.0.0 - 2018-05-07

### Breaking changes

- Past tense verb + brief issue/enhancement description in `ComponentName` ([#100](https://github.com/shopify/polaris/pull/100))

Contributed from the community:

- Past tense verb + brief issue/enhancement description in `ComponentName` ([#100](https://github.com/shopify/polaris/pull/100)) (thanks [@username](https://github.com/username) for the [original issue](issue link)) and/or (thanks [@username](https://github.com/username) for the [pull request](pull request link))
```

The possible groups in which to categorize changes are:

- Breaking changes
- New components
- Enhancements (new variations, accessibility improvements, etc.)
- Design updates (non-breaking design changes implemented in code)
- Bug fixes
- Documentation
- Dependency upgrades
- Development workflow (new yarn commands or changes to existing commands)
- Code quality (non-trivial changes to code which effect the private API)
- Deprecations

## Out of scope for `CHANGELOG.md`

Generally, changes related to these topics can be omitted:

- Style guide (update the [“What’s new” page](https://github.com/Shopify/polaris-styleguide/tree/master/pages/whats-new) instead)
- UI Kit (unless noteworthy)
- Dev dependencies upgrades
- Chores (infrastructure, release process…)

## Unreleased changes

Unreleased changes must go under in the `polaris-react/UNRELEASED.md` file:

```md
### Bug fixes

- Fixed something ([#100](https://github.com/shopify/polaris/pull/100))
```

Entries must be moved from `polaris-react/UNRELEASED.md` to `polaris-react/CHANGELOG.md` at each release.

## Versioning scheme

Because we expose both React components (for which the markup, including class names, is an implementation detail) and static CSS/Sass builds, the versioning scheme for Polaris is somewhat unusual. The following sections detail what kinds of changes result in each of major, minor, and patch version bumps:

### Major

- Removal of a component
- Removal of a prop from a component
- Change to the type accepted for a prop
- Breaking changes to minimum version of dependencies
- Breaking changes to public Sass variables, functions and mixins

### Minor

- New component
- New prop for a component
- Additional type accepted for a prop
- Deprecation of a component, prop, public Sass variable, function, or mixin (ahead of its removal in the next major version)

### Patch

- Breaking change to the HTML generated by a component, including addition, removal, or renaming of classes
- Changes that do not impact public APIs
- Non-breaking changes to minimum version of dependencies
- Breaking changes to private Sass variables, functions, and mixins

## Creating a new release

> This action can only be performed by a @Shopify member. Reach out to someone in @Shopify if you need assistance.

Follow the following steps to deploy a new version of Polaris:

1. Checkout the `main` branch and pull the latest commits

   `git checkout main && git pull`

1. Create a new `polaris-release` branch from `main`

   `git checkout -b polaris-release`

1. Migrate all entries from `UNRELEASED.md` to `CHANGELOG.md` ([see example](https://github.com/Shopify/polaris/pull/5254/files#diff-06572a96a58dc510037d5efa622f9bec8519bc1beab13c9f251e97e657a9d4ed))

1. Commit changelog updates

   `git add . && git commit -m "Polaris vX.X.X release"`

1. Version and tag the new release

   `yarn version`

1. Verify the new tag was created and is linked to the last commit in the last release

1. Push the `polaris-release` branch to the remote repository with tags

   `git push origin polaris-release --follow-tags`

1. Create a new PR to merge `polaris-release` into `main` in GitHub

1. Deploy the tagged commit in shipit

1. Once successfully deployed, merge the release PR into `main`

   Use the **Rebase and merge** option when merging. Squashing your commits can lead to loosing the tagged commit.

1. Add release notes to the new release

   a. Copy release notes from `CHANGELOG.md`

   b. Select the latest tag from the [Releases](https://github.com/Shopify/polaris/releases) section, click `Edit tag`, and paste the release notes into the release description

   c. Push the `Publish Release` button
