---
name: Content/Product content
slug: product-content
icon: IconProductContent
keywords:
  - content standards
  - content guidelines
  - content strategy practices
  - interface content
  - strategic language
  - edit content
  - editing content
  - reading level
  - writes
  - writing
  - writing tips
  - language tips
  - content tips
  - designing
  - strategic designing
  - action
  - consistency
  - consistent
  - writing public-facing text
  - public-facing text
  - writing public-facing copy
  - public-facing copy
  - writing public-facing content
  - public-facing content
---

# Product content

Thoughtful, consistent interface content is a core element of a well-designed
user experience.

Our content standards will help you understand how to think strategically about
the language in your products and apps. They’ll also give you clear, tactical
suggestions designed to help you use language to craft better experiences.

[Each component](/components/get-started) also includes content guidelines about
how to write for specific interface elements.

---

## Respond to merchant needs

<!-- keywords: real merchants, language, empathy -->

Not everyone is a confident writer, but everyone can improve their content by
making sure it responds to the needs of their audience. Keep in mind that real people
rely on Shopify every day to run their businesses. The product, feature, or app
you’re building can make a big difference to the people using it. Take some time
to learn about who they are, what they need, and the language they use.

---

## Use plain language

<!-- keywords: literacy, english as a first language, english as a second language, esl, short sentences, using headings, using bullets, scannable, jargon, idioms, terminology, industry standard, repeated words, small screens -->

Shopify merchants are busy people who may be running their online business in
addition to having a full-time job, managing their family life, and doing a
million other things. They’re also located all over the world, have varying
levels of literacy, and some may not speak English as their first language. Some content can be translated poorly and can be misinterpreted.

Writing using plain language doesn’t mean dumbing content down. It’s
about making sure language is straightforward and communicates concepts as
efficiently as possible. As a benchmark, we consider plain language to be a United States grade 7 reading level. Grade reading level can be checked using apps like http://www.hemingwayapp.com/ or https://readable.com/.

If you create content for Shopify’s other audiences, such as [merchant’s customers](/content/merchant-to-customer), the same plain language guidelines apply. Some reading level exceptions can be made for audiences with a high level of subject matter expertise in an area, like partner developers. Keep in mind that we still aim to keep technical content readable by other UX disciplines who want to learn about technical subjects, or for those who speak English as a second language.

### Tips

- Write short sentences (no more than 15–20 words).
- Use headings and bullets to make your content easier to scan.
- Avoid jargon and always choose a short, simple word over a long and
  complicated one.
- Avoid idioms and phrases with indirect or ironic meanings.
- Only use industry-standard terminology when you have reason to believe it will
  improve understanding. Spend time researching what words people use,
  rather than defaulting to what corporations call things.
- Edit unnecessary or repeated words.
- Write for small screens first. Constraints can help you focus on the most
  important message.
- Read your content out loud. If you get tripped up or it doesn’t sound like
  something a human would say, your content needs to be edited.

---

## Encourage action

<!-- keywords: content structure, actionable language, writing action, button copy, prioritizing tasks, call to action -->

People use Shopify to get things done, whether they’re managing a store, or making a purchase. Content should be written and structured
to help the reader understand and take the most important actions.

### Tips

- Calls to action on buttons and links should start with a strong verb that
  describes the action a person will take when they click.
- Always prioritize the most important information and task — don’t make people
  dig to find what they care about.
- Break down complicated tasks into steps that help people focus on one thing
  at a time.
- Use the [active voice](/content/grammar-and-mechanics#basics) to clarify the
  subject and the action.

---

## Be consistent

<!-- keywords: consistency in copy, consistent copy, consistent nouns, consistent verbs, writing consistently, write consistently, synonyms, plain language, word list, merchant words, merchant language, merchant terms -->

To help your audience understand key concepts and actions they can take, use
consistent nouns (words used to identify people, places, or things) and verbs
(action words) wherever possible.

### Tips

- Get in the habit of making a list of all the most important verbs and nouns in
  the experience you’re building.
- Look at your word list. Does each word clearly describe the object or action
  it represents in the simplest way possible?
- Does your language reflect how people think and the words they use?
- Identify synonyms (a word or phrase that means exactly or nearly the same as
  another word or phrase in the same language), and eliminate them. Each
  important object and action should have a single word to represent it.
